==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/frm_select_folder.js <==
_me = frm_select_folder.prototype;
function frm_select_folder(){};

/**
 * @brief   Universal form for selecting folder.
 * This form is used e.g. for moving folder (in inc/obj_context_folder.js) or for
 * moving or copying items (in inc/obj_context_item.js).
 * Form contains only one 'obj_tree_folder' for selection. 
 * 
 * @param[in]  sMainLabel  [string] Label of the popup window.
 * @param[in]  sLabel      [string] TODO
 * @param[in]  sAccountID  [string] Optional, used together with 'sFolderID' for
 * preselecting folder in the tree. 
 * @param[in]  sFolderID   [string] Optional, when 'sAccountID' isn't specified, this
 * argument is ignored. 
 * @param[in]  aResponse   [array]  Optional callback function, has form [object, method, [arg3, arg4, ...]].
 *	Arg1 and arg2 are taken from selected folder and have IDs of selected account and selected folder:
 *		- arg1 = selected account, e.g. 'admin@merakdemo.com
 *		- arg2 = selected folder, e.g. 'INBOX'
 *
 *	Example:
 *		- [this, '__moveFolder']   Call __moveFolder(sSelectedAccount, sSelectedFolder)
 *		- [this, '__copyOrMoveItem', ['copy', arg['aid']]     Call  __copyOrMoveItem(sSelectedAccount, sSelectedFolder, 'copy', arg['aid'])
 *
 * @param[in]  bDisableAccounts  [boolean]   When true, selection of the account will disable 'OK' button.
 *    Used in moving items, where moving item directly under account is disabled, item must
 *    always be in some folder.  
 * @param[in]  bOneAccount       [boolean]   When true, only selected account will be listed 
 * @param[in]  sFilterType      [string]   When specified, only folders of that type will be listed. (Types can be 'M', 'C', 'J, ...)
 * 
 * @see  objects/frm_select_folder.xml
 * @see  inc/frm_select_folder.js
 */
_me.__constructor = function(sMainLabel, sAccountID, sFolderID, aResponse, bDisableAccounts, bOneAccount, sFilterType, sFilterRights, bDisableNewButton){

	var me = this;
	if (sMainLabel)
		this._title(sMainLabel);

	// Create formular from template
	this._draw('frm_select_folder', 'main');
	if (bDisableNewButton)
		this._size(300,400);
	else
		this._size(350,400);
	
	if (sAccountID)
	{
		// TODO function _setActive also opens folder, it's strange
		var aPreselectFolder = [sAccountID];
		var sPartialPath = sAccountID;
		var aSplitFolder = sFolderID.split('/');
		for (var dir in aSplitFolder) {
			sPartialPath += '/'+aSplitFolder[dir];
			aPreselectFolder.push(sPartialPath);
		}
		this.tree_folder._value(aPreselectFolder);
		
		// Preselect folder, set active account
		var sFullFolderPath = sAccountID + ((sFolderID) ? '/'+sFolderID : '');
		this.tree_folder._setActive(sFullFolderPath);

		// Set type of the items to be filetered
		if (bOneAccount)
			this.tree_folder.sFilterAccountId = sAccountID;

		/*
		if (bFilterItems && sFolderID)
		{
			sFolderType = dataSet.get("folders",[sAccountID,sFolderID,'TYPE']);
			this.tree_folder.sFilterFolderType = sFolderType;
		}
		*/
	}
	else{
		var ds = dataSet.get('folders');
		for(var sFullFolderPath in ds)
            this.tree_folder._open(sFullFolderPath,'minus');
	}
	
	if (sFilterType)
		this.tree_folder._sFilterFolderType = sFilterType;
	if (sFilterRights)
		this.tree_folder._sFilterRights = sFilterRights;
		
	// Redraw the folder tree
	if ((sAccountID && bOneAccount) || sFilterType)
		this.tree_folder._fill();

	if (bDisableAccounts)
	{
		// Set initial state of 'OK' button. When some folder is selected permit 'OK button, disable otherwise.
		if (this.tree_folder._getActive()[1])
			this.x_btn_ok._disabled(false);
		else
			this.x_btn_ok._disabled(true);

		// Set callback function. When folder is selected permit 'OK' button, disable otherwise.
		this.tree_folder._obeyEvent('onclick',[this,'_onFolderClick']);

		this._onFolderClick = function(e,arg){
			if (arg.arg.fid)
				me.x_btn_ok._disabled(false);
			else
				me.x_btn_ok._disabled(true);
		}
	}

	// This function is triggered when 'OK' button is pressed.
	this.x_btn_ok._onclick = function()
	{
		// When user has specified callback function call it with two first arguments
		// sSelectedAccount, sSelectedFolder and the rest of user provided parameters.
		// E.g. [this, '__copyOrMoveItem', ['copy', arg['aid']]     Call  __copyOrMoveItem(sSelectedAccount, sSelectedFolder, 'copy', arg['aid'])

		var aSelected = me.tree_folder._getActive();
		executeCallbackFunction(aResponse, aSelected[0], aSelected[1]);
		me._destruct();
	}
	
	if (!bDisableNewButton) {
		this._create('x_btn_new_folder', 'obj_button', 'footer');
		this.x_btn_new_folder._value('FORM_BUTTONS::NEW_FOLDER');
		this.x_btn_new_folder._onclick = function() {
			var aSelected = me.tree_folder._getActive();
			gui._create('frm_add_folder','frm_add_folder','','',aSelected[0],aSelected[1]); 
		}
	}
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/frm_select_folder.js <==
_me = frm_select_folder.prototype;
function frm_select_folder(){};

/**
 * @brief   Universal form for selecting folder.
 * This form is used e.g. for moving folder (in inc/obj_context_folder.js) or for
 * moving or copying items (in inc/obj_context_item.js).
 * Form contains only one 'obj_tree_folder' for selection. 
 * 
 * @param[in]  sMainLabel  [string] Label of the popup window.
 * @param[in]  sLabel      [string] TODO
 * @param[in]  sAccountID  [string] Optional, used together with 'sFolderID' for
 * preselecting folder in the tree. 
 * @param[in]  sFolderID   [string] Optional, when 'sAccountID' isn't specified, this
 * argument is ignored. 
 * @param[in]  aResponse   [array]  Optional callback function, has form [object, method, [arg3, arg4, ...]].
 *	Arg1 and arg2 are taken from selected folder and have IDs of selected account and selected folder:
 *		- arg1 = selected account, e.g. 'admin@merakdemo.com
 *		- arg2 = selected folder, e.g. 'INBOX'
 *
 *	Example:
 *		- [this, '__moveFolder']   Call __moveFolder(sSelectedAccount, sSelectedFolder)
 *		- [this, '__copyOrMoveItem', ['copy', arg['aid']]     Call  __copyOrMoveItem(sSelectedAccount, sSelectedFolder, 'copy', arg['aid'])
 *
 * @param[in]  bDisableAccounts  [boolean]   When true, selection of the account will disable 'OK' button.
 *    Used in moving items, where moving item directly under account is disabled, item must
 *    always be in some folder.  
 * @param[in]  bOneAccount       [boolean]   When true, only selected account will be listed 
 * @param[in]  sFilterType      [string]   When specified, only folders of that type will be listed. (Types can be 'M', 'C', 'J, ...)
 * 
 * @see  objects/frm_select_folder.xml
 * @see  inc/frm_select_folder.js
 */
_me.__constructor = function(sMainLabel, sAccountID, sFolderID, aResponse, bDisableAccounts, bOneAccount, sFilterType, sFilterRights, bDisableNewButton){

	var me = this;
	if (sMainLabel)
		this._title(sMainLabel);

	// Create formular from template
	this._draw('frm_select_folder', 'main');
	if (bDisableNewButton)
		this._size(300,400,true);
	else
		this._size(350,400,true);
	
	if (sAccountID)
	{
		// TODO function _setActive also opens folder, it's strange
		var aPreselectFolder = [sAccountID];
		var sPartialPath = sAccountID;
		var aSplitFolder = sFolderID.split('/');
		for (var dir in aSplitFolder) {
			sPartialPath += '/'+aSplitFolder[dir];
			aPreselectFolder.push(sPartialPath);
		}
		this.tree_folder._value(aPreselectFolder);
		
		// Preselect folder, set active account
		var sFullFolderPath = sAccountID + ((sFolderID) ? '/'+sFolderID : '');
		this.tree_folder._setActive(sFullFolderPath);

		// Set type of the items to be filetered
		if (bOneAccount)
			this.tree_folder.sFilterAccountId = sAccountID;

		/*
		if (bFilterItems && sFolderID)
		{
			sFolderType = dataSet.get("folders",[sAccountID,sFolderID,'TYPE']);
			this.tree_folder.sFilterFolderType = sFolderType;
		}
		*/
	}
	else{
		var ds = dataSet.get('folders');
		for(var sFullFolderPath in ds)
            this.tree_folder._open(sFullFolderPath,'minus');
	}
	
	if (sFilterType)
		this.tree_folder._sFilterFolderType = sFilterType;
	if (sFilterRights)
		this.tree_folder._sFilterRights = sFilterRights;
		
	// Redraw the folder tree
	if ((sAccountID && bOneAccount) || sFilterType)
		this.tree_folder._fill();

	if (bDisableAccounts)
	{
		// Set initial state of 'OK' button. When some folder is selected permit 'OK button, disable otherwise.
		if (this.tree_folder._getActive()[1])
			this.x_btn_ok._disabled(false);
		else
			this.x_btn_ok._disabled(true);

		// Set callback function. When folder is selected permit 'OK' button, disable otherwise.
		this.tree_folder._obeyEvent('onclick',[this,'_onFolderClick']);

		this._onFolderClick = function(e,arg){
			if (arg.arg.fid)
				me.x_btn_ok._disabled(false);
			else
				me.x_btn_ok._disabled(true);
		}
	}

	// This function is triggered when 'OK' button is pressed.
	this.x_btn_ok._onclick = function()
	{
		// When user has specified callback function call it with two first arguments
		// sSelectedAccount, sSelectedFolder and the rest of user provided parameters.
		// E.g. [this, '__copyOrMoveItem', ['copy', arg['aid']]     Call  __copyOrMoveItem(sSelectedAccount, sSelectedFolder, 'copy', arg['aid'])
		var aSelected = me.tree_folder._getActive();
		
		executeCallbackFunction(aResponse, aSelected[0], aSelected[1]);
		me._destruct();
	}
	
	if (!bDisableNewButton) {
		this._create('x_btn_new_folder', 'obj_button', 'footer');
		this.x_btn_new_folder._value('FORM_BUTTONS::NEW_FOLDER');
		this.x_btn_new_folder._onclick = function() {
			var aSelected = me.tree_folder._getActive();
			gui._create('frm_add_folder','frm_add_folder','','',aSelected[0],aSelected[1]); 
		}
	}
};
